<?php
/**
 * Careerpress Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage Careerpress Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function careerpress_pro_custom_colors_css() {
  	$options= careerpress_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
	## Background Color
	--------------------------------------------------------------*/
	.backtotop,
	#respond input[type="submit"]:hover,
	#respond input[type="submit"]:focus,
	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus,
	.btn-transparent,
	.btn-primary:hover,
	.btn-primary:focus,
	.single-wrapper #reply-title:after,
	.single-wrapper .comments-title:after,
	#subscribe-submit input[type=submit],
	#featured-services .more-link a:before, 
	.posts-wrapper .more-link a:before,
	.seperator,
	#our-services .entry-content .seperator,
	#secondary .widget-title:after,
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	#subscribe-submit button[type=submit] {
	    background-color: '. esc_attr( $color_value ) .';
	}

	/*--------------------------------------------------------------
	## Text Color
	--------------------------------------------------------------*/

	#respond input[type="submit"],
	a:hover,
	a:focus,
	a:active,
	.main-navigation a:hover,
	.main-navigation a:focus,
	.main-navigation ul.nav-menu > li > a:hover,
	.main-navigation ul.nav-menu > li > a:focus,
	.navigation.post-navigation a:hover,
	.navigation.posts-navigation a:hover,
	.navigation.post-navigation a:focus,
	.navigation.posts-navigation a:focus,
	.widget_popular_post h3 a:hover,
	.widget_popular_post h3 a:focus,
	.widget_popular_post a:hover time,
	.widget_popular_post a:focus time,
	.widget_latest_post h3 a:hover,
	.widget_latest_post h3 a:focus,
	.widget_latest_post a:hover time,
	.widget_latest_post a:focus time,
	.widget_featured_courses .course-wrapper h5 a:hover,
	.widget_featured_courses .course-wrapper h5 a:focus,
	.widget_featured_courses .tp-course-price,
	.widget_popular_courses .course-wrapper h5 a:hover,
	.widget_popular_courses .course-wrapper h5 a:focus,
	.widget_popular_courses .tp-course-price,
	.widget_featured_courses .tp-course-price.free,
	.widget_popular_courses .tp-course-price.free,
	.reply a,
	.comment-meta .url,
	.comment-meta .fn,
	.comment-metadata a:hover time,
	.comment-metadata a:focus time,
	.section-subtitle,
	.hero-content-wrapper p a:hover,
	ul.post-categories li a:hover,
	span.member-position,
	#testimonial span.position,
	.cat-links a:hover,
	.single-wrapper .entry-meta span a:hover, 
	.single-wrapper .entry-meta span a:focus,
	.single-wrapper .entry-meta span.byline a.fn:hover,
	.single-wrapper .entry-meta span.byline a.fn:focus,
	#colophon .site-info a,
	.site-title a:hover, 
	.site-title a:focus,
	.main-navigation ul.nav-menu li.current-menu-item > a,
	#top-bar .contact-info a,
	input[type="submit"],
	#featured-services article a .fa, 
	#our-services .icon-container a .fa {
	    color: '. esc_attr( $color_value ) .';
	}

	.loader-container svg,
	.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
	.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
	.main-navigation li.search-menu a:hover svg,
	.main-navigation li.search-menu a:focus svg,
	.main-navigation li.search-menu a.search-active svg,
	.main-navigation a:hover svg,
	.main-navigation a:focus svg,
	.main-navigation ul.nav-menu > li > a:hover svg,
	.main-navigation ul.nav-menu > li > a:focus svg,
	.navigation.post-navigation a:hover svg,
	.navigation.posts-navigation a:hover svg,
	.navigation.post-navigation a:focus svg,
	.navigation.posts-navigation a:focus svg,
	.icon-container svg,
	.widget_search form.search-form button.search-submit:hover svg,
	.widget_search form.search-form button.search-submit:focus svg {
	    fill:'. esc_attr( $color_value ) .';
	}

	/*--------------------------------------------------------------
	## Border Color
	--------------------------------------------------------------*/
	#respond input[type="submit"],
	#respond input[type="submit"]:hover,
	#respond input[type="submit"]:focus,
	input[type="submit"],
	input[type="submit"]:hover,
	input[type="submit"]:focus {
	    border-color: '. esc_attr( $color_value ) .';
	}

	#our-services .hentry:hover .entry-container {
	    border-bottom-color: '. esc_attr( $color_value ) .';
	}

	/*--------------------------------------------------------------
	## Responsive Color
	--------------------------------------------------------------*/
	@media screen and (min-width: 1024px) {
	    .main-navigation ul#primary-menu > li.current-menu-item > a:after {
	        background-color: '. esc_attr( $color_value ) .';
	    }
	    .main-navigation ul.sub-menu li:hover > a,
	    .main-navigation ul.sub-menu li:focus > a,
	    .main-navigation ul#primary-menu ul li.current-menu-item > a,
	    .main-navigation ul li:hover > a,
	    .main-navigation ul#primary-menu ul li:hover > a,
	    .main-navigation ul#primary-menu ul li:focus > a {
	        color: '. esc_attr( $color_value ) .';
	    }
	    #search:before {
	        border-bottom-color: '. esc_attr( $color_value ) .';
	    }
	    .main-navigation form.search-form {
	        border-color: '. esc_attr( $color_value ) .';
	    }
	}

	/*--------------------------------------------------------------
	## Preloader
	--------------------------------------------------------------*/
	@keyframes preloader {
	    0% {height:5px;transform:translateY(0px);background: '. esc_attr( $color_value ) .';}
	    25% {height:30px;transform:translateY(15px);background: '. esc_attr( $color_value ) .';}
	    50% {height:5px;transform:translateY(0px);background: '. esc_attr( $color_value ) .';}
	    100% {height:5px;transform:translateY(0px);background: '. esc_attr( $color_value ) .';}
	}
	';

	/**
	 * Filters Careerpress Pro custom colors CSS.
	 *
	 * @since Careerpress Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'careerpress_pro_custom_colors_css', $css );
}
