<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Careerpress Pro
 * @since Careerpress Pro 1.0.0
 * @return array An array of default values
 */

function careerpress_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$careerpress_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#23272a',
		'header_tagline_color'			=> '#23272a',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ffb531',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'careerpress-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'careerpress-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'careerpress-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'careerpress-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,service,about,cta,features,projects,team,testimonial,client,blog,promotion',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'careerpress-pro' ),
		'hide_category'					=> false,
		'archive_column'				=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_social_enable'			=> false,
		'topbar_phone_label'			=> esc_html__( 'Any Questions? Call Us:', 'careerpress-pro' ),
		'topbar_phone'					=> esc_html__( '+0 00 000000000', 'careerpress-pro' ),


		// Slider
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'title_text_align'				=>'slider-left',
		'slider_btn_label'				=> esc_html__( 'Learn More', 'careerpress-pro' ),
		'slider_alt_btn_label'			=> esc_html__( 'Contact Us', 'careerpress-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_column'				=> 'col-3',
		'service_readmore_title'		=> esc_html__( 'Learn More', 'careerpress-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_sub_title'				=> esc_html__( 'About Us', 'careerpress-pro' ),
		'about_title'					=> esc_html__( 'We value your trust and build your dreams!', 'careerpress-pro' ),
		'about_description'				=> esc_html__( 'With a community of over 400 million users (and a majority age group being 18 to 29), wouldn’t you want to make sure you’re monitoring what people are posting on social networks? Especially if the demographic of your audience falls in that age range.', 'careerpress-pro' ),
		'about_btn_title'				=> esc_html__( 'Learn More', 'careerpress-pro' ),

		// call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_sub_title'					=> esc_html__( 'Case Study', 'careerpress-pro' ),
		'cta_title'						=> esc_html__( 'We have been building for over 10 years.', 'careerpress-pro' ),
		'cta_btn_title'					=> esc_html__( 'Contact Us', 'careerpress-pro' ),
		'cta_description'				=> esc_html__( 'All of our Client Care team works in our offices and is an experiemnced Web Meeting user ready to help you. Never outsourced.', 'careerpress-pro' ),

		// Features
		'features_section_enable'		=> true,
		'features_content_type'			=> 'category',
		'features_count'				=> 3,
		'features_column'				=> 'col-3',
		'features_sub_title'			=> esc_html__( 'Our Key Features', 'careerpress-pro' ),
		'features_title'				=> esc_html__( 'What we offer you', 'careerpress-pro' ),

		// Projects
		'projects_section_enable'		=> true,
		'projects_content_type'			=> 'category',
		'projects_count'				=> 4,
		'projects_column'				=> 'col-4',
		'projects_sub_title'			=> esc_html__( 'Our Projects', 'careerpress-pro' ),
		'projects_title'				=> esc_html__( 'What we do for your Success', 'careerpress-pro' ),
		'projects_description'			=> esc_html__( 'With a community of over 400 million users (and a majority age group being 18 to 29), wouldn’t you want to make sure you’re monitoring what people are posting on social networks? Especially if the demographic of your audience falls in that age range.', 'careerpress-pro' ),
		'projects_btn_title'			=> esc_html__( 'View All Projects', 'careerpress-pro' ),

		// team
		'team_section_enable'			=> true,
		'team_content_type'				=> 'category',
		'team_count'					=> 4,
		'team_column'					=> 'col-4',
		'team_title'					=> esc_html__( 'Meet our friendly &#38; helpful team', 'careerpress-pro' ),
		'team_sub_title'				=> esc_html__( 'Our Team', 'careerpress-pro' ),
		'team_description'				=> esc_html__( 'With a community of over 400 million users (and a majority age group being 18 to 29), wouldn’t you want to make sure you’re monitoring what people are posting on social networks? Especially if the demographic of your audience falls in that age range.', 'careerpress-pro' ),
		'team_btn_title'				=> esc_html__( 'View All Team', 'careerpress-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_title'				=> esc_html__( 'Loved by business, and individuals across the globe', 'careerpress-pro' ),
		'testimonial_sub_title'			=> esc_html__( 'Testimonials', 'careerpress-pro' ),

		// clients
		'client_section_enable'			=> true,
		'client_column'					=> 5,
		'client_content_type'			=> 'category',
		'client_count'					=> 5,

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'Know what&#39;s happening around us', 'careerpress-pro' ),
		'blog_sub_title'				=> esc_html__( 'Latest Blog', 'careerpress-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Blogs', 'careerpress-pro' ),

		// Promotion
		'promotion_section_enable'		=> true,
		'promotion_content_type'		=> 'page',
		'promotion_title'				=> esc_html__( 'A better way to hire our best help', 'careerpress-pro' ),
		'promotion_btn_title'			=> esc_html__( 'Learn More', 'careerpress-pro' ),
		'promotion_alt_btn_title'		=> esc_html__( 'Contact Us', 'careerpress-pro' ),

	);

	$output = apply_filters( 'careerpress_pro_default_theme_options', $careerpress_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}