<?php
/**
 * Projects Section options
 *
 * @package Theme Palace
 * @subpackage Careerpress Pro
 * @since Careerpress Pro 1.0.0
 */

// Add Projects section
$wp_customize->add_section( 'careerpress_pro_projects_section', array(
	'title'             => esc_html__( 'Projects','careerpress-pro' ),
	'description'       => esc_html__( 'Projects Section options.', 'careerpress-pro' ),
	'panel'             => 'careerpress_pro_front_page_panel',
) );

// Projects content enable control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_section_enable]', array(
	'default'			=> 	$options['projects_section_enable'],
	'sanitize_callback' => 'careerpress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Careerpress_Pro_Switch_Control( $wp_customize, 'careerpress_pro_theme_options[projects_section_enable]', array(
	'label'             => esc_html__( 'Projects Section Enable', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_projects_section',
	'on_off_label' 		=> careerpress_pro_switch_options(),
) ) );

// projects sub title setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['projects_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[projects_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_projects_section',
	'active_callback' 	=> 'careerpress_pro_is_projects_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'careerpress_pro_theme_options[projects_sub_title]', array(
		'selector'            => '#projects .section-header span.section-subtitle',
		'settings'            => 'careerpress_pro_theme_options[projects_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'careerpress_pro_projects_sub_title_partial',
    ) );
}

// projects title setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['projects_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[projects_title]', array(
	'label'           	=> esc_html__( 'Title', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_projects_section',
	'active_callback' 	=> 'careerpress_pro_is_projects_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'careerpress_pro_theme_options[projects_title]', array(
		'selector'            => '#projects .section-header h2.section-title',
		'settings'            => 'careerpress_pro_theme_options[projects_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'careerpress_pro_projects_title_partial',
    ) );
}

// projects description setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['projects_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[projects_description]', array(
	'label'           	=> esc_html__( 'Description', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_projects_section',
	'active_callback' 	=> 'careerpress_pro_is_projects_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'careerpress_pro_theme_options[projects_description]', array(
		'selector'            => '#projects .section-content p',
		'settings'            => 'careerpress_pro_theme_options[projects_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'careerpress_pro_projects_description_partial',
    ) );
}

// projects content type control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_column]', array(
	'default'          	=> $options['projects_column'],
	'sanitize_callback' => 'careerpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[projects_column]', array(
	'label'             => esc_html__( 'Column Layout', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_projects_section',
	'type'				=> 'select',
	'active_callback' 	=> 'careerpress_pro_is_projects_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'careerpress-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'careerpress-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'careerpress-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_count]', array(
	'default'          	=> $options['projects_count'],
	'sanitize_callback' => 'careerpress_pro_sanitize_number_range',
	'validate_callback' => 'careerpress_pro_validate_projects_count',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[projects_count]', array(
	'label'             => esc_html__( 'Number of Projects', 'careerpress-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_projects_section',
	'active_callback'   => 'careerpress_pro_is_projects_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Projects content type control and setting
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_content_type]', array(
	'default'          	=> $options['projects_content_type'],
	'sanitize_callback' => 'careerpress_pro_sanitize_select',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[projects_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_projects_section',
	'type'				=> 'select',
	'active_callback' 	=> 'careerpress_pro_is_projects_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'careerpress-pro' ),
		'post' 		=> esc_html__( 'Post', 'careerpress-pro' ),
		'category' 	=> esc_html__( 'Category', 'careerpress-pro' ),
	),
) );

for ( $i = 1; $i <= $options['projects_count']; $i++ ) :

	// projects pages drop down chooser control and setting
	$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_content_page_' . $i . ']', array(
		'sanitize_callback' => 'careerpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Careerpress_Pro_Dropdown_Chooser( $wp_customize, 'careerpress_pro_theme_options[projects_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'careerpress-pro' ), $i ),
		'section'           => 'careerpress_pro_projects_section',
		'choices'			=> careerpress_pro_page_choices(),
		'active_callback'	=> 'careerpress_pro_is_projects_section_content_page_enable',
	) ) );

	// projects posts drop down chooser control and setting
	$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_content_post_' . $i . ']', array(
		'sanitize_callback' => 'careerpress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Careerpress_Pro_Dropdown_Chooser( $wp_customize, 'careerpress_pro_theme_options[projects_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'careerpress-pro' ), $i ),
		'section'           => 'careerpress_pro_projects_section',
		'choices'			=> careerpress_pro_post_choices(),
		'active_callback'	=> 'careerpress_pro_is_projects_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'careerpress_pro_theme_options[projects_content_category]', array(
	'sanitize_callback' => 'careerpress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Careerpress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'careerpress_pro_theme_options[projects_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'careerpress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'careerpress-pro' ),
	'section'           => 'careerpress_pro_projects_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'careerpress_pro_is_projects_section_content_category_enable'
) ) );

// projects readmore title setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['projects_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[projects_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_projects_section',
	'active_callback' 	=> 'careerpress_pro_is_projects_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'careerpress_pro_theme_options[projects_btn_title]', array(
		'selector'            => '#projects .more-link a.btn',
		'settings'            => 'careerpress_pro_theme_options[projects_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'careerpress_pro_projects_btn_title_partial',
    ) );
}

// projects readmore title setting and control
$wp_customize->add_setting( 'careerpress_pro_theme_options[projects_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'careerpress_pro_theme_options[projects_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'careerpress-pro' ),
	'section'        	=> 'careerpress_pro_projects_section',
	'active_callback' 	=> 'careerpress_pro_is_projects_section_enable',
	'type'				=> 'url',
) );
